@@ -13,6 +13,7 @@ import websocket  # type: ignore
 from apispec import APISpec  # type: ignore
 from apispec_webframeworks.flask import FlaskPlugin  # type: ignore
 from flask import Flask, jsonify, request, send_file
+from flask_cors import CORS  # type: ignore
 from flask_swagger_ui import get_swaggerui_blueprint  # type: ignore
 from werkzeug.utils import secure_filename
 
@@ -34,6 +35,7 @@ spec = APISpec(
 )
 
 app = Flask(__name__)
+CORS(app)
 
 
 # TODO find out why long-lasting connection is not possible (it is getting disconnected after few minutes)
@@ -412,7 +414,7 @@ def main():
 
     swaggerui_blueprint = get_swaggerui_blueprint(
         SWAGGER_URL,  # Swagger UI static files will be mapped to '{SWAGGER_URL}/dist/'
-        f"./api/swagger.json"
+        "./api/swagger.json"
     )
 
     # Register blueprint at URL
